const chokidar = require('chokidar');
const express = require('express');
const app = express();

const jsRoute = '/assets/js/mythical-player.dist.js';

function tmplIndex() {
  return String.raw`
    <!DOCTYPE html>
    <html lang="en">
      <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta http-equiv="X-UA-Compatible" content="ie=edge">
        <link rel="preconnect" href="https://fonts.googleapis.com">
        <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
        <link
          href="https://fonts.googleapis.com/css2?family=Fira+Sans:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap"
          rel="stylesheet"
        >
        <title>mythical-player</title>
      </head>
      <body style="font-family: 'Fira Sans', sans-serif; background-color: #121212;">
      <div style="display: flex; justify-content: center; width: 100%; min-height: 100dvh;">
        <div style="width: 96%; max-width: 960px">
          <div id="player-default" style="font-size: 62.5%"></div>
        </div>
      </div>
      <script src="${jsRoute}"></script>
      <script>
        fetch('/assets/media/playlist.json')
          .then(response => response.json())
          .then(playlist => {
            MythicalPlayer({
              placeholder: document.getElementById('player-default'),
              props: {
                style: {
                  ambient: 'dark',
                  accent: 'blue',
                  height: '620px',
                  trackInfoHorizontal: 'left'
                },
                playlist,
                useShadowDOM: true,
                list: {
                  showCovers: true,
                  showTrackNumber: true,
                  showIconIsPlaying: true,
                  showFileExtension: true
                },
                id: 'default'
              }
            });
          });
      </script>
      </body>
    </html>
  `;
}

app.get('/', (req, res) => {
  res.send(tmplIndex());
});
app.get(jsRoute, (req, res) => {
  res.sendFile('bundle/mythical-player.dist.js', {
    root: __dirname
  });
});
app.use('/assets/media', express.static(process.env.MEDIA_FOLDER));

const port = process.env.PORT;
app.listen(port, () => {
  console.log(`Example app listening on port ${port}`);
});

const watcher = chokidar.watch(['js', 'sass'], {
  ignored: (path, stats) =>
    stats?.isFile() && !path.endsWith('.scss') && !path.endsWith('.js'),
  persistent: true
});
watcher.on('change', (path, stats) => {
  if (stats) console.log(`File ${path} changed`);
  require('./build.js').buildJs();
});
